;; Generated package description from mode: lisp-data; .el  -*- gnome-dark-styleno-byte-compile: t -*-
(define-package "gnome-dark-style" "0.2.3" "Sync theme with GNOME color-scheme" '((emacs "30.1")) :commit "a2e9248ea09776c13966d8181d3f2078e9a1c7ba" :authors '(("David Dimagid" . "davidimagid@gmail.com")) :maintainer '("David Dimagid" . "davidimagid@gmail.com") :keywords '("themes" "gnome" "sync" "dark" "light" "color-scheme") :url "https://github.com/dimagid/gnome-dark-style")
